==> azureml_designer_classic_modules-0.0.100-py3-none-any.whl: azureml/studio/modulehost/handler/parameter_handler.py <==
from enum import Enum
from urllib.parse import unquote

from azureml.studio.modulehost.attributes import ItemInfo
from azureml.studio.common.credential import SecureString
from azureml.studio.common.datatable.data_table import DataTableColumnSelection
from azureml.studio.common.error import ParameterParsingError
from azureml.studio.core.logger import module_host_logger
from azureml.studio.common.parameter_range import ParameterRangeSettings


class ParameterHandler:
    def handle_argument_string(self, value_string, parameter_annotation):
        if not value_string:
            return None

        try:
            if issubclass(parameter_annotation.data_type, Enum):
                module_host_logger.info('Parse enum parameter')
                return self.parse_enum(value_string, parameter_annotation)
            elif parameter_annotation.data_type is bool:
                module_host_logger.info('Parse bool parameter')
                return self.parse_bool(value_string, parameter_annotation)
            elif parameter_annotation.data_type is int:
                module_host_logger.info('Parse int parameter')
                return self.parse_int(value_string, parameter_annotation)
            elif parameter_annotation.data_type is float:
                module_host_logger.info('Parse float parameter')
                return self.parse_float(value_string, parameter_annotation)
            elif parameter_annotation.data_type is str:
                module_host_logger.info('Parse str parameter')
                return self.parse_str(value_string, parameter_annotation)
            elif parameter_annotation.data_type is DataTableColumnSelection:
                module_host_logger.info('Parse ColumnSelection parameter')
                return self.parse_column_selection(value_string, parameter_annotation)
            elif parameter_annotation.data_type is SecureString:
                module_host_logger.info('Parse SecureString parameter')
                return self.parse_secure_string(value_string, parameter_annotation)
            elif parameter_annotation.data_type is ParameterRangeSettings:
                module_host_logger.info('Parse ParameterRangeSettings parameter')
                return self.parse_parameter_range_settings(value_string, parameter_annotation)
            else:
                module_host_logger.info('Return without parsing')
                return value_string
        except Exception:
            raise ParameterParsingError(
                arg_name_or_column='value_string',
                to_type=parameter_annotation.data_type.__name__,
                from_type='str',
                arg_value=value_string)

    @staticmethod
    def parse_enum(value_string, parameter_annotation):
        enum_type = parameter_annotation.data_type
        enum_value = ItemInfo.get_enum_value_by_name(enum_type, value_string)
        return enum_value

    @staticmethod
    def parse_bool(value_string, parameter_annotation):
        if value_string.casefold() == "True".casefold():
            return True
        elif value_string.casefold() == "False".casefold():
            return False
        else:
            raise Exception('Parse error.')

    @staticmethod
    def parse_int(value_string, parameter_annotation):
        return int(value_string)

    @staticmethod
    def parse_float(value_string, parameter_annotation):
        return float(value_string)

    @staticmethod
    def parse_str(value_string, parameter_annotation):
        return value_string

    @staticmethod
    def parse_column_selection(value_string, parameter_annotation=None):
        json_string = unquote(value_string)
        return DataTableColumnSelection(json_string)

    @staticmethod
    def parse_secure_string(value_string, parameter_annotation):
        return SecureString(value_string)

    @staticmethod
    def parse_parameter_range_settings(value_string, parameter_annotation):
        try:
            value = float(value_string)
            if parameter_annotation.is_int:
                value = int(value)
            return ParameterRangeSettings.from_value(value)

        except ValueError:
            module_host_logger.warning(f"Failed to parse ParameterRangeSettings from value. Try parse from JSON.")
            return ParameterRangeSettings.from_json(value_string)

==> azureml_designer_classic_modules-0.0.110-py3-none-any.whl: azureml/studio/modulehost/handler/parameter_handler.py <==
from enum import Enum
from urllib.parse import unquote

from azureml.studio.modulehost.attributes import ItemInfo
from azureml.studio.common.credential import SecureString
from azureml.studio.common.datatable.data_table import DataTableColumnSelection
from azureml.studio.common.error import ParameterParsingError
from azureml.studio.core.logger import module_host_logger
from azureml.studio.common.parameter_range import ParameterRangeSettings


class ParameterHandler:
    def handle_argument_string(self, value_string, parameter_annotation):
        if not value_string:
            return None

        try:
            if issubclass(parameter_annotation.data_type, Enum):
                module_host_logger.info('Parse enum parameter')
                return self.parse_enum(value_string, parameter_annotation)
            elif parameter_annotation.data_type is bool:
                module_host_logger.info('Parse bool parameter')
                return self.parse_bool(value_string, parameter_annotation)
            elif parameter_annotation.data_type is int:
                module_host_logger.info('Parse int parameter')
                return self.parse_int(value_string, parameter_annotation)
            elif parameter_annotation.data_type is float:
                module_host_logger.info('Parse float parameter')
                return self.parse_float(value_string, parameter_annotation)
            elif parameter_annotation.data_type is str:
                module_host_logger.info('Parse str parameter')
                return self.parse_str(value_string, parameter_annotation)
            elif parameter_annotation.data_type is DataTableColumnSelection:
                module_host_logger.info('Parse ColumnSelection parameter')
                return self.parse_column_selection(value_string, parameter_annotation)
            elif parameter_annotation.data_type is SecureString:
                module_host_logger.info('Parse SecureString parameter')
                return self.parse_secure_string(value_string, parameter_annotation)
            elif parameter_annotation.data_type is ParameterRangeSettings:
                module_host_logger.info('Parse ParameterRangeSettings parameter')
                return self.parse_parameter_range_settings(value_string, parameter_annotation)
            else:
                module_host_logger.info('Return without parsing')
                return value_string
        except Exception:
            raise ParameterParsingError(
                arg_name_or_column=parameter_annotation.name,
                to_type=parameter_annotation.data_type.__name__,
                from_type='str',
                arg_value=value_string)

    @staticmethod
    def parse_enum(value_string, parameter_annotation):
        enum_type = parameter_annotation.data_type
        enum_value = ItemInfo.get_enum_value_by_name(enum_type, value_string)
        return enum_value

    @staticmethod
    def parse_bool(value_string, parameter_annotation):
        if value_string.casefold() == "True".casefold():
            return True
        elif value_string.casefold() == "False".casefold():
            return False
        else:
            raise Exception('Parse error.')

    @staticmethod
    def parse_int(value_string, parameter_annotation):
        return int(value_string)

    @staticmethod
    def parse_float(value_string, parameter_annotation):
        return float(value_string)

    @staticmethod
    def parse_str(value_string, parameter_annotation):
        return value_string

    @staticmethod
    def parse_column_selection(value_string, parameter_annotation=None):
        json_string = unquote(value_string)
        return DataTableColumnSelection(json_string)

    @staticmethod
    def parse_secure_string(value_string, parameter_annotation):
        return SecureString(value_string)

    @staticmethod
    def parse_parameter_range_settings(value_string, parameter_annotation):
        try:
            value = float(value_string)
            if parameter_annotation.is_int:
                value = int(value)
            return ParameterRangeSettings.from_value(value)

        except ValueError:
            module_host_logger.warning(f"Failed to parse ParameterRangeSettings from value. Try parse from JSON.")
            return ParameterRangeSettings.from_json(value_string)
